[−][src]Struct alloc_many_collections::vec::Vec
A contiguous growable array type, written Vec<T> but pronounced 'vector'.
Methods
impl<A, T> Vec<A, T> where
A: Alloc, [src]
A: Alloc,
pub fn new() -> Self[src]
Constructs a new, empty Vec<T>
pub fn capacity(&self) -> usize[src]
Returns the number of elements the vector can hold without reallocating.
pub fn push(&mut self, elem: T)[src]
Appends an element to the back of a collection.
pub fn pop(&mut self) -> Option<T>[src]
Removes the last element from a vector and returns it, or None if it is empty.
pub fn reserve(&mut self, additional: usize)[src]
Reserves capacity for at least additional more elements to be inserted in the given
Vec